# coding=utf-8
import os
from .acws import AcWebSocket
from .reader import AcLiveReader

__author__ = 'dolacmeo'


class AcLiveRoom(AcWebSocket):
    live_obj = None

    def reader(self, seq_id: int, command, result):
        if command == 'Basic.ClientConfigGet':
            self._start_live()
        if command == 'LiveCmd.ZtLiveCsEnterRoomAck':
            self.task(*self.protos.ZtLiveCsHeartbeat_Request())
            self.task(*self.protos.ZtLiveInteractiveMessage_Request())
        elif command == "LiveCmd.ZtLiveCsHeartbeatAck" and seq_id % 5 == 0:
            self.task(*self.protos.ZtLiveInteractiveMessage_Request())
        self.output(seq_id, command, result)

    def output(self, seq_id: int, command, result):
        pass

    def _start_live(self):
        if self.live_obj is None:
            return False
        cmd = self.protos.ZtLiveCsEnterRoom_Request(self.live_obj.live)
        return self.task(*cmd)

    def enter_room(self, uid: int):
        self.live_obj = self.acer.acfun.AcLiveUp(uid)
        if self.live_obj.past_time < 0:
            return False
        if self._main_thread is None or self.is_close is True:
            self.run()
        return True


class AcLiveScreen(AcLiveRoom):
    live_reader = None

    def display(self, data: list):
        if self.live_reader is None:
            return None
        result = self.live_reader(data)
        for item in result:
            print(item)
        return True

    def output(self, seq_id: int, command, result):
        if command.startswith("LivePush.") and result:
            self.display(result)

    def enter_room(self, uid: int, msg_temp: [str, None] = None, filters: [dict, None] = None):
        self.live_obj = self.acer.acfun.AcLiveUp(uid)
        gifts = self.live_obj.gift_list()
        self.live_reader = AcLiveReader(gift=gifts, output_temp=msg_temp, filters=filters)
        if self.live_obj.past_time < 0:
            return False
        if self._main_thread is None or self.is_close is True:
            self.run()
        return True


class AcLiveDanmaku(AcLiveRoom):
    live_reader = None
    log_file_path = None

    def output(self, seq_id: int, command, result):
        if command.startswith("LivePush.") and result:
            if self.live_reader is None:
                return None
            data = self.live_reader(result)
            if len(data) == 0:
                return None
            with open(self.log_file_path, "a", encoding="utf8") as log:
                log.write("\n" + "\n".join(data))
            return True

    def enter_room(self, uid: int, log_path: [str, os.PathLike]):
        self.live_obj = self.acer.acfun.AcLiveUp(uid)
        if self.live_obj.past_time < 0:
            return False
        create_time = self.live_obj.raw_data.get("createTime", 0)
        self.log_file_path = os.path.join(log_path, f"{uid}_{create_time}.log")
        tmp = "{time}\t{user}\t{content}"
        filters = {"mtype": ["ZtLiveScActionSignal"], "signal": ["CommonActionSignalComment"]}
        self.live_reader = AcLiveReader(output_temp=tmp, filters=filters,
                                        time_tans=False, userid_only=True, type_name=False)
        if self._main_thread is None or self.is_close is True:
            self.run()
        return True



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: SessionRaw.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x10SessionRaw.proto\x12\x15\x41\x63\x46unDanmu.Im.Message\"q\n\nSessionRaw\x12\x37\n\x03raw\x18\x01 \x03(\x0b\x32*.AcFunDanmu.Im.Message.SessionRaw.RawEntry\x1a*\n\x08RawEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c:\x02\x38\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'SessionRaw_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _SESSIONRAW_RAWENTRY._options = None
  _SESSIONRAW_RAWENTRY._serialized_options = b'8\001'
  _SESSIONRAW._serialized_start=43
  _SESSIONRAW._serialized_end=156
  _SESSIONRAW_RAWENTRY._serialized_start=114
  _SESSIONRAW_RAWENTRY._serialized_end=156
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: GroupMembersBriefInfo.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import User_pb2 as User__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1bGroupMembersBriefInfo.proto\x12\x1b\x41\x63\x46unDanmu.Im.Cloud.Message\x1a\nUser.proto\"s\n\x15GroupMembersBriefInfo\x12\x13\n\x0bmemberCount\x18\x01 \x01(\x05\x12-\n\ntopMembers\x18\x02 \x03(\x0b\x32\x19.AcFunDanmu.Im.Basic.User\x12\x16\n\x0elastUpdateTime\x18\x03 \x01(\x03\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'GroupMembersBriefInfo_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _GROUPMEMBERSBRIEFINFO._serialized_start=72
  _GROUPMEMBERSBRIEFINFO._serialized_end=187
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: SessionFolderSyncResponse.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import SessionFolderBasic_pb2 as SessionFolderBasic__pb2
import SessionReferenceUpdateItem_pb2 as SessionReferenceUpdateItem__pb2
import SyncCookie_pb2 as SyncCookie__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1fSessionFolderSyncResponse.proto\x12!AcFunDanmu.Im.Cloud.SessionFolder\x1a\x18SessionFolderBasic.proto\x1a SessionReferenceUpdateItem.proto\x1a\x10SyncCookie.proto\"\xef\x02\n\x19SessionFolderSyncResponse\x12\x33\n\nsyncCookie\x18\x01 \x01(\x0b\x32\x1f.AcFunDanmu.Im.Basic.SyncCookie\x12Q\n\x12sessionFolderBasic\x18\x02 \x03(\x0b\x32\x35.AcFunDanmu.Im.Cloud.SessionFolder.SessionFolderBasic\x12L\n\x05\x61\x64\x64\x65\x64\x18\x03 \x03(\x0b\x32=.AcFunDanmu.Im.Cloud.SessionFolder.SessionReferenceUpdateItem\x12N\n\x07removed\x18\x04 \x03(\x0b\x32=.AcFunDanmu.Im.Cloud.SessionFolder.SessionReferenceUpdateItem\x12\x14\n\x0cnotFullFetch\x18\x05 \x01(\x08\x12\x16\n\x0e\x63learLocalData\x18\x06 \x01(\x08\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'SessionFolderSyncResponse_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _SESSIONFOLDERSYNCRESPONSE._serialized_start=149
  _SESSIONFOLDERSYNCRESPONSE._serialized_end=516
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ForbiddenState.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x14\x46orbiddenState.proto\x12\x1b\x41\x63\x46unDanmu.Im.Cloud.Message*S\n\x0e\x46orbiddenState\x12\x1b\n\x17UNKNOWN_FORBIDDEN_STATE\x10\x00\x12\x10\n\x0cUN_FORBIDDEN\x10\x01\x12\x12\n\x0e\x46ORBID_MESSAGE\x10\x02\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ForbiddenState_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _FORBIDDENSTATE._serialized_start=53
  _FORBIDDENSTATE._serialized_end=136
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: VoiceCallUserStatus.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import CallParam_pb2 as CallParam__pb2
import User_pb2 as User__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x19VoiceCallUserStatus.proto\x12\x1e\x41\x63\x46unDanmu.Im.Cloud.Voice.Call\x1a\x0f\x43\x61llParam.proto\x1a\nUser.proto\"\xf7\x02\n\x13VoiceCallUserStatus\x12\'\n\x04user\x18\x01 \x01(\x0b\x32\x19.AcFunDanmu.Im.Basic.User\x12R\n\x06status\x18\x02 \x01(\x0e\x32\x42.AcFunDanmu.Im.Cloud.Voice.Call.VoiceCallUserStatus.UserCallStatus\x12\x14\n\x0c\x61\x63\x63\x65ptTimeMs\x18\x03 \x01(\x03\x12<\n\tcallParam\x18\x04 \x01(\x0b\x32).AcFunDanmu.Im.Cloud.Voice.Call.CallParam\"\x8e\x01\n\x0eUserCallStatus\x12\x0e\n\nUS_UNKNOWN\x10\x00\x12\x0c\n\x08\x41\x43\x43\x45PTED\x10\x01\x12\x0c\n\x08REJECTED\x10\x02\x12\x0e\n\nREQUESTING\x10\x03\x12\x11\n\rNORMAL_CLOSED\x10\x04\x12\x12\n\x0eTIMEOUT_CLOSED\x10\x05\x12\x0b\n\x07\x42USYING\x10\x06\x12\x0c\n\x08\x46INISHED\x10\x07\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'VoiceCallUserStatus_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _VOICECALLUSERSTATUS._serialized_start=91
  _VOICECALLUSERSTATUS._serialized_end=466
  _VOICECALLUSERSTATUS_USERCALLSTATUS._serialized_start=324
  _VOICECALLUSERSTATUS_USERCALLSTATUS._serialized_end=466
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: SessionFolderCreateResponse.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import SessionFolderInfo_pb2 as SessionFolderInfo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!SessionFolderCreateResponse.proto\x12!AcFunDanmu.Im.Cloud.SessionFolder\x1a\x17SessionFolderInfo.proto\"n\n\x1bSessionFolderCreateResponse\x12O\n\x11sessionFolderInfo\x18\x01 \x01(\x0b\x32\x34.AcFunDanmu.Im.Cloud.SessionFolder.SessionFolderInfob\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'SessionFolderCreateResponse_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _SESSIONFOLDERCREATERESPONSE._serialized_start=97
  _SESSIONFOLDERCREATERESPONSE._serialized_end=207
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: RelationEvent.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x13RelationEvent.proto\x12\x1f\x41\x63\x46unDanmu.Im.Cloud.Data.Update\"\xce\x01\n\rRelationEvent\x12[\n\x11relationEventType\x18\x01 \x01(\x0e\x32@.AcFunDanmu.Im.Cloud.Data.Update.RelationEvent.RelationEventType\x12\x0e\n\x06\x66romId\x18\x02 \x01(\x03\x12\x10\n\x08targetId\x18\x03 \x01(\x03\">\n\x11RelationEventType\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x0c\n\x08\x46OLLOWED\x10\x01\x12\x0e\n\nUNFOLLOWED\x10\x02\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'RelationEvent_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _RELATIONEVENT._serialized_start=57
  _RELATIONEVENT._serialized_end=263
  _RELATIONEVENT_RELATIONEVENTTYPE._serialized_start=201
  _RELATIONEVENT_RELATIONEVENTTYPE._serialized_end=263
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: GroupJoinRequestAckRequest.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n GroupJoinRequestAckRequest.proto\x12\x1b\x41\x63\x46unDanmu.Im.Cloud.Message\"\xa0\x02\n\x1aGroupJoinRequestAckRequest\x12\r\n\x05reqId\x18\x01 \x01(\x03\x12\x0f\n\x07groupId\x18\x02 \x01(\t\x12\x62\n\x10groupJoinAckType\x18\x03 \x01(\x0e\x32H.AcFunDanmu.Im.Cloud.Message.GroupJoinRequestAckRequest.GroupJoinAckType\x12\x14\n\x0c\x61uditComment\x18\x04 \x01(\t\x12\x1f\n\x17ignoreFutureJoinRequest\x18\x05 \x01(\x08\"G\n\x10GroupJoinAckType\x12\x10\n\x0cUNKNOWN_TYPE\x10\x00\x12\t\n\x05\x41GREE\x10\x01\x12\n\n\x06REFUSE\x10\x02\x12\n\n\x06IGNORE\x10\x03\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'GroupJoinRequestAckRequest_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _GROUPJOINREQUESTACKREQUEST._serialized_start=66
  _GROUPJOINREQUESTACKREQUEST._serialized_end=354
  _GROUPJOINREQUESTACKREQUEST_GROUPJOINACKTYPE._serialized_start=283
  _GROUPJOINREQUESTACKREQUEST_GROUPJOINACKTYPE._serialized_end=354
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: RedPacket.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0fRedPacket.proto\x12\x1b\x41\x63\x46unDanmu.Im.Cloud.Message\"\xd8\x02\n\tRedPacket\x12\x13\n\x0bredPacketId\x18\x01 \x01(\t\x12K\n\rredPacketType\x18\x02 \x01(\x0e\x32\x34.AcFunDanmu.Im.Cloud.Message.RedPacket.RedPacketType\x12\r\n\x05\x65xtra\x18\x03 \x01(\x0c\x12\x13\n\x0b\x61ssignedUid\x18\x04 \x01(\x03\"\xc4\x01\n\rRedPacketType\x12\x1b\n\x17UNKNOWN_RED_PACKET_TYPE\x10\x00\x12\x0c\n\x08PERSONAL\x10\x01\x12\x17\n\x13GROUP_RANDOM_AMOUNT\x10\x02\x12\x1a\n\x16GROUP_IDENTICAL_AMOUNT\x10\x03\x12\'\n#GROUP_ASSIGNED_MEMBER_RANDOM_AMOUNT\x10\x04\x12*\n&GROUP_ASSIGNED_MEMBER_IDENTICAL_AMOUNT\x10\x05\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'RedPacket_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _REDPACKET._serialized_start=49
  _REDPACKET._serialized_end=393
  _REDPACKET_REDPACKETTYPE._serialized_start=197
  _REDPACKET_REDPACKETTYPE._serialized_end=393
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: GroupJoinReq.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import GroupMember_pb2 as GroupMember__pb2
import JoinRequestStatus_pb2 as JoinRequestStatus__pb2
import User_pb2 as User__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x12GroupJoinReq.proto\x12\x1b\x41\x63\x46unDanmu.Im.Cloud.Message\x1a\x11GroupMember.proto\x1a\x17JoinRequestStatus.proto\x1a\nUser.proto\"\xc6\x02\n\x0cGroupJoinReq\x12\x0e\n\x06reqSeq\x18\x01 \x01(\x03\x12*\n\x07inviter\x18\x02 \x01(\x0b\x32\x19.AcFunDanmu.Im.Basic.User\x12+\n\x08invitees\x18\x03 \x03(\x0b\x32\x19.AcFunDanmu.Im.Basic.User\x12\x0f\n\x07\x66indWay\x18\x04 \x01(\x05\x12\x13\n\x0b\x64\x65scContent\x18\x05 \x01(\t\x12>\n\x06status\x18\x06 \x01(\x0e\x32..AcFunDanmu.Im.Cloud.Message.JoinRequestStatus\x12\x11\n\ttimestamp\x18\x07 \x01(\x03\x12T\n\x12inviteeMembersRole\x18\x08 \x01(\x0e\x32\x38.AcFunDanmu.Im.Cloud.Message.GroupMember.GroupMemberRoleb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'GroupJoinReq_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _GROUPJOINREQ._serialized_start=108
  _GROUPJOINREQ._serialized_end=434
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: VoiceCallAlreadyProcessedEvent.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$VoiceCallAlreadyProcessedEvent.proto\x12\x1e\x41\x63\x46unDanmu.Im.Cloud.Voice.Call\" \n\x1eVoiceCallAlreadyProcessedEventb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'VoiceCallAlreadyProcessedEvent_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _VOICECALLALREADYPROCESSEDEVENT._serialized_start=72
  _VOICECALLALREADYPROCESSEDEVENT._serialized_end=104
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: SessionMuteResponse.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import ChatSession_pb2 as ChatSession__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x19SessionMuteResponse.proto\x12\x15\x41\x63\x46unDanmu.Im.Message\x1a\x11\x43hatSession.proto\"J\n\x13SessionMuteResponse\x12\x33\n\x07session\x18\x01 \x01(\x0b\x32\".AcFunDanmu.Im.Message.ChatSessionb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'SessionMuteResponse_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _SESSIONMUTERESPONSE._serialized_start=71
  _SESSIONMUTERESPONSE._serialized_end=145
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: GroupSettingBatchUpdate.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import Location_pb2 as Location__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1dGroupSettingBatchUpdate.proto\x12\x1b\x41\x63\x46unDanmu.Im.Cloud.Message\x1a\x0eLocation.proto\"\xe0\x02\n\x17GroupSettingBatchUpdate\x12P\n\x06\x66ields\x18\x01 \x03(\x0e\x32@.AcFunDanmu.Im.Cloud.Message.GroupSettingBatchUpdate.UpdateField\x12\x11\n\tgroupName\x18\x02 \x01(\t\x12\x14\n\x0cgroupHeadUrl\x18\x03 \x01(\t\x12\x37\n\x08location\x18\x04 \x01(\x0b\x32%.AcFunDanmu.Im.Cloud.Message.Location\x12\x0b\n\x03tag\x18\x05 \x01(\t\x12\x14\n\x0cintroduction\x18\x06 \x01(\t\"n\n\x0bUpdateField\x12\x12\n\x0eUN_KNOWN_FIELD\x10\x00\x12\x0e\n\nGROUP_NAME\x10\x01\x12\x12\n\x0eGROUP_HEAD_URL\x10\x02\x12\x0c\n\x08LOCATION\x10\x03\x12\x07\n\x03TAG\x10\x04\x12\x10\n\x0cINTRODUCTION\x10\x05\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'GroupSettingBatchUpdate_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _GROUPSETTINGBATCHUPDATE._serialized_start=79
  _GROUPSETTINGBATCHUPDATE._serialized_end=431
  _GROUPSETTINGBATCHUPDATE_UPDATEFIELD._serialized_start=321
  _GROUPSETTINGBATCHUPDATE_UPDATEFIELD._serialized_end=431
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: SessionRemoveRequest.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import ChatTargetType_pb2 as ChatTargetType__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1aSessionRemoveRequest.proto\x12\x15\x41\x63\x46unDanmu.Im.Message\x1a\x14\x43hatTargetType.proto\"\xad\x01\n\x14SessionRemoveRequest\x12\x10\n\x08targetId\x18\x01 \x01(\x03\x12=\n\x0e\x63hatTargetType\x18\x02 \x01(\x0e\x32%.AcFunDanmu.Im.Message.ChatTargetType\x12\x12\n\ncategoryId\x18\x03 \x01(\x05\x12\x13\n\x0bstrTargetId\x18\x04 \x01(\t\x12\x1b\n\x13notCleanAllMessages\x18\x05 \x01(\x08\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'SessionRemoveRequest_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _SESSIONREMOVEREQUEST._serialized_start=76
  _SESSIONREMOVEREQUEST._serialized_end=249
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: RequsetBasicInfo.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import AppInfo_pb2 as AppInfo__pb2
import DeviceInfo_pb2 as DeviceInfo__pb2
import EnvInfo_pb2 as EnvInfo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x16RequsetBasicInfo.proto\x12\x13\x41\x63\x46unDanmu.Im.Basic\x1a\rAppInfo.proto\x1a\x10\x44\x65viceInfo.proto\x1a\rEnvInfo.proto\"\xf7\x02\n\x10RequsetBasicInfo\x12@\n\nclientType\x18\x01 \x01(\x0e\x32,.AcFunDanmu.Im.Basic.DeviceInfo.PlatformType\x12\x10\n\x08\x64\x65viceId\x18\x02 \x01(\t\x12\x10\n\x08\x63lientIp\x18\x03 \x01(\t\x12\x12\n\nappVersion\x18\x04 \x01(\t\x12\x0f\n\x07\x63hannel\x18\x05 \x01(\t\x12-\n\x07\x61ppInfo\x18\x06 \x01(\x0b\x32\x1c.AcFunDanmu.Im.Basic.AppInfo\x12\x33\n\ndeviceInfo\x18\x07 \x01(\x0b\x32\x1f.AcFunDanmu.Im.Basic.DeviceInfo\x12-\n\x07\x65nvInfo\x18\x08 \x01(\x0b\x32\x1c.AcFunDanmu.Im.Basic.EnvInfo\x12\x12\n\nclientPort\x18\t \x01(\x05\x12\x10\n\x08location\x18\n \x01(\t\x12\x0b\n\x03kpf\x18\x0b \x01(\t\x12\x12\n\nclientIpV6\x18\x0c \x01(\tb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'RequsetBasicInfo_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _REQUSETBASICINFO._serialized_start=96
  _REQUSETBASICINFO._serialized_end=471
# @@protoc_insertion_point(module_scope)



"""Classes for encoding and decoding varint types"""
from google.protobuf.internal import wire_format, encoder, decoder


def encode_uvarint(value):
    """Encode a long or int into a bytearray."""
    if not isinstance(value, int):
        raise TypeError("UVarInt encode requires a int type")

    output = bytearray()
    encoder._EncodeVarint(output.extend, value)
    return output


def decode_uvarint(buf, pos):
    """Decode bytearray into a long."""
    # Convert buffer to string
    # buf = buf.decode('latin')
    value, pos = decoder._DecodeVarint(buf, pos)
    return (value, pos)


def encode_varint(value):
    """Encode a long or int into a bytearray."""
    if not isinstance(value, int):
        raise TypeError("VarInt encode requires an int type")

    output = bytearray()
    encoder._EncodeSignedVarint(output.extend, value)
    return output


def decode_varint(buf, pos):
    """Decode bytearray into a long."""
    # Convert buffer to string
    # buf = buf.decode('latin')
    value, pos = decoder._DecodeSignedVarint(buf, pos)
    return (value, pos)


def encode_svarint(value):
    """Zigzag encode the potentially signed value prior to encoding"""
    # zigzag encode value
    return encode_uvarint(wire_format.ZigZagEncode(value))


def decode_svarint(buf, pos):
    """Decode bytearray into a long."""
    output, pos = decode_uvarint(buf, pos)
    # zigzag encode value
    return wire_format.ZigZagDecode(output), pos



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: NoticeMetaType.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x14NoticeMetaType.proto\x12\x1b\x41\x63\x46unDanmu.Im.Cloud.Message*\xaf\x01\n\x0eNoticeMetaType\x12\x1c\n\x18UNKNOWN_NOTICE_META_TYPE\x10\x00\x12\x1b\n\x17\x43OMMON_NOTICE_META_TYPE\x10\x01\x12\"\n\x1e\x43ONFIRM_INVITE_INTO_GROUP_META\x10\x02\x12 \n\x1c\x43ONFIRM_JOIN_INTO_GROUP_META\x10\x03\x12\x1c\n\x18LINKED_PROFILE_META_TYPE\x10\x04\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'NoticeMetaType_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _NOTICEMETATYPE._serialized_start=54
  _NOTICEMETATYPE._serialized_end=229
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: InvitationOperator.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import User_pb2 as User__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x18InvitationOperator.proto\x12\x1b\x41\x63\x46unDanmu.Im.Cloud.Message\x1a\nUser.proto\"\xdb\x01\n\x12InvitationOperator\x12+\n\x08operator\x18\x01 \x01(\x0b\x32\x19.AcFunDanmu.Im.Basic.User\x12R\n\x0coperatorRole\x18\x02 \x01(\x0e\x32<.AcFunDanmu.Im.Cloud.Message.InvitationOperator.OperatorRole\"D\n\x0cOperatorRole\x12\x10\n\x0cUNKNOWN_ROLE\x10\x00\x12\n\n\x06\x43OMMON\x10\x01\x12\t\n\x05\x41\x44MIN\x10\x02\x12\x0b\n\x07MANAGER\x10\x03\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'InvitationOperator_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _INVITATIONOPERATOR._serialized_start=70
  _INVITATIONOPERATOR._serialized_end=289
  _INVITATIONOPERATOR_OPERATORROLE._serialized_start=221
  _INVITATIONOPERATOR_OPERATORROLE._serialized_end=289
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: B2CMerchantSessionFolderCheckEvent.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import User_pb2 as User__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(B2CMerchantSessionFolderCheckEvent.proto\x12!AcFunDanmu.Im.Cloud.SessionFolder\x1a\nUser.proto\"\x8b\x01\n\"B2CMerchantSessionFolderCheckEvent\x12\'\n\x04user\x18\x01 \x01(\x0b\x32\x19.AcFunDanmu.Im.Basic.User\x12\x10\n\x08subBizId\x18\x02 \x01(\x05\x12\x12\n\nsyncOffset\x18\x03 \x01(\x03\x12\x16\n\x0elastUpdateTime\x18\x04 \x01(\x03\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'B2CMerchantSessionFolderCheckEvent_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _B2CMERCHANTSESSIONFOLDERCHECKEVENT._serialized_start=92
  _B2CMERCHANTSESSIONFOLDERCHECKEVENT._serialized_end=231
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ZtDrawGiftInfo.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x14ZtDrawGiftInfo.proto\x12\nAcFunDanmu\"\xfa\x01\n\x0eZtDrawGiftInfo\x12\x13\n\x0bscreenWidth\x18\x01 \x01(\x03\x12\x14\n\x0cscreenHeight\x18\x02 \x01(\x03\x12\x39\n\tdrawPoint\x18\x03 \x03(\x0b\x32&.AcFunDanmu.ZtDrawGiftInfo.ZtDrawPoint\x1a\x81\x01\n\x0bZtDrawPoint\x12\x12\n\nmarginLeft\x18\x01 \x01(\x03\x12\x11\n\tmarginTop\x18\x02 \x01(\x03\x12\x12\n\nscaleRatio\x18\x03 \x01(\x01\x12\x0e\n\x06handup\x18\x04 \x01(\x08\x12\x12\n\npointWidth\x18\x05 \x01(\x03\x12\x13\n\x0bpointHeight\x18\x06 \x01(\x03\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ZtDrawGiftInfo_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _ZTDRAWGIFTINFO._serialized_start=37
  _ZTDRAWGIFTINFO._serialized_end=287
  _ZTDRAWGIFTINFO_ZTDRAWPOINT._serialized_start=158
  _ZTDRAWGIFTINFO_ZTDRAWPOINT._serialized_end=287
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: SessionSearchRequest.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import TimeFilter_pb2 as TimeFilter__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1aSessionSearchRequest.proto\x12\x1a\x41\x63\x46unDanmu.Im.Cloud.Search\x1a\x10TimeFilter.proto\"\xc8\x01\n\x14SessionSearchRequest\x12\x11\n\tgroupName\x18\x01 \x03(\t\x12\x12\n\nmemberName\x18\x02 \x03(\t\x12\r\n\x05query\x18\x03 \x03(\t\x12\x10\n\x08\x66ileName\x18\x04 \x03(\t\x12:\n\ntimeFilter\x18\x05 \x01(\x0b\x32&.AcFunDanmu.Im.Cloud.Search.TimeFilter\x12\x1a\n\x12msgCountPerSession\x18\x06 \x01(\x05\x12\x10\n\x08memberId\x18\x07 \x03(\tb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'SessionSearchRequest_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _SESSIONSEARCHREQUEST._serialized_start=77
  _SESSIONSEARCHREQUEST._serialized_end=277
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ZtLiveCsEnterRoom.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x17ZtLiveCsEnterRoom.proto\x12\nAcFunDanmu\"\x8b\x01\n\x11ZtLiveCsEnterRoom\x12\x10\n\x08isAuthor\x18\x01 \x01(\x08\x12\x16\n\x0ereconnectCount\x18\x02 \x01(\x05\x12\x15\n\rlastErrorCode\x18\x03 \x01(\x05\x12\x17\n\x0f\x65nterRoomAttach\x18\x04 \x01(\t\x12\x1c\n\x14\x63lientLiveSdkVersion\x18\x05 \x01(\t\"3\n\x14ZtLiveCsEnterRoomAck\x12\x1b\n\x13heartbeatIntervalMs\x18\x01 \x01(\x03\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ZtLiveCsEnterRoom_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _ZTLIVECSENTERROOM._serialized_start=40
  _ZTLIVECSENTERROOM._serialized_end=179
  _ZTLIVECSENTERROOMACK._serialized_start=181
  _ZTLIVECSENTERROOMACK._serialized_end=232
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: VoiceCallAcceptedEvent.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1cVoiceCallAcceptedEvent.proto\x12\x1e\x41\x63\x46unDanmu.Im.Cloud.Voice.Call\",\n\x16VoiceCallAcceptedEvent\x12\x12\n\nsignalData\x18\x01 \x01(\x0c\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'VoiceCallAcceptedEvent_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _VOICECALLACCEPTEDEVENT._serialized_start=64
  _VOICECALLACCEPTEDEVENT._serialized_end=108
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: Location.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0eLocation.proto\x12\x1b\x41\x63\x46unDanmu.Im.Cloud.Message\"K\n\x08Location\x12\r\n\x05poiId\x18\x01 \x01(\x03\x12\x10\n\x08latitude\x18\x02 \x01(\t\x12\x11\n\tlongitude\x18\x03 \x01(\t\x12\x0b\n\x03poi\x18\x04 \x01(\tb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'Location_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _LOCATION._serialized_start=47
  _LOCATION._serialized_end=122
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: SessionFolderDataUpdate.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import SessionFolderBasic_pb2 as SessionFolderBasic__pb2
import SessionReferenceUpdateItem_pb2 as SessionReferenceUpdateItem__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1dSessionFolderDataUpdate.proto\x12\x1f\x41\x63\x46unDanmu.Im.Cloud.Data.Update\x1a\x18SessionFolderBasic.proto\x1a SessionReferenceUpdateItem.proto\"\x8a\x02\n\x17SessionFolderDataUpdate\x12Q\n\x12sessionFolderBasic\x18\x01 \x03(\x0b\x32\x35.AcFunDanmu.Im.Cloud.SessionFolder.SessionFolderBasic\x12L\n\x05\x61\x64\x64\x65\x64\x18\x02 \x03(\x0b\x32=.AcFunDanmu.Im.Cloud.SessionFolder.SessionReferenceUpdateItem\x12N\n\x07removed\x18\x03 \x03(\x0b\x32=.AcFunDanmu.Im.Cloud.SessionFolder.SessionReferenceUpdateItemb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'SessionFolderDataUpdate_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _SESSIONFOLDERDATAUPDATE._serialized_start=127
  _SESSIONFOLDERDATAUPDATE._serialized_end=393
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: B2CSessionRemoveRequest.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import ChatTarget_pb2 as ChatTarget__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1d\x42\x32\x43SessionRemoveRequest.proto\x12\x15\x41\x63\x46unDanmu.Im.Message\x1a\x10\x43hatTarget.proto\"\x81\x01\n\x17\x42\x32\x43SessionRemoveRequest\x12\x35\n\nchatTarget\x18\x01 \x01(\x0b\x32!.AcFunDanmu.Im.Message.ChatTarget\x12\x12\n\ncategoryId\x18\x02 \x01(\x05\x12\x1b\n\x13notCleanAllMessages\x18\x03 \x01(\x08\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'B2CSessionRemoveRequest_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _B2CSESSIONREMOVEREQUEST._serialized_start=75
  _B2CSESSIONREMOVEREQUEST._serialized_end=204
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: AccountType.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x11\x41\x63\x63ountType.proto\x12\x15\x41\x63\x46unDanmu.Im.Message*A\n\x0b\x41\x63\x63ountType\x12\n\n\x06UNKNOW\x10\x00\x12\x0c\n\x08OFFICIAL\x10\x01\x12\n\n\x06NORMAL\x10\x02\x12\x0c\n\x08STRANGER\x10\x03\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'AccountType_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _ACCOUNTTYPE._serialized_start=44
  _ACCOUNTTYPE._serialized_end=109
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: KsImDataUpdatePushPayload.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import KsImDataUpdateType_pb2 as KsImDataUpdateType__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1fKsImDataUpdatePushPayload.proto\x12\x1f\x41\x63\x46unDanmu.Im.Cloud.Data.Update\x1a\x18KsImDataUpdateType.proto\"\x82\x01\n\x19KsImDataUpdatePushPayload\x12\x41\n\x04type\x18\x01 \x01(\x0e\x32\x33.AcFunDanmu.Im.Cloud.Data.Update.KsImDataUpdateType\x12\x0f\n\x07\x63ontent\x18\x02 \x01(\x0c\x12\x11\n\ttimestamp\x18\x03 \x01(\x03\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'KsImDataUpdatePushPayload_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _KSIMDATAUPDATEPUSHPAYLOAD._serialized_start=95
  _KSIMDATAUPDATEPUSHPAYLOAD._serialized_end=225
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: PushServiceToken.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x16PushServiceToken.proto\x12\x13\x41\x63\x46unDanmu.Im.Basic\"\xc0\x02\n\x10PushServiceToken\x12@\n\x08pushType\x18\x01 \x01(\x0e\x32..AcFunDanmu.Im.Basic.PushServiceToken.PushType\x12\r\n\x05token\x18\x02 \x01(\x0c\x12\x15\n\risPassThrough\x18\x03 \x01(\x08\"\xc3\x01\n\x08PushType\x12\x14\n\x10kPushTypeInvalid\x10\x00\x12\x11\n\rkPushTypeAPNS\x10\x01\x12\x13\n\x0fkPushTypeXmPush\x10\x02\x12\x13\n\x0fkPushTypeJgPush\x10\x03\x12\x13\n\x0fkPushTypeGtPush\x10\x04\x12\x13\n\x0fkPushTypeOpPush\x10\x05\x12\x13\n\x0fkPushTypeVvPush\x10\x06\x12\x13\n\x0fkPushTypeHwPush\x10\x07\x12\x10\n\x0ckPushTypeFcm\x10\x08\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'PushServiceToken_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _PUSHSERVICETOKEN._serialized_start=48
  _PUSHSERVICETOKEN._serialized_end=368
  _PUSHSERVICETOKEN_PUSHTYPE._serialized_start=173
  _PUSHSERVICETOKEN_PUSHTYPE._serialized_end=368
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: RegisterResponse.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import AccessPointsConfig_pb2 as AccessPointsConfig__pb2
import SdkOption_pb2 as SdkOption__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x16RegisterResponse.proto\x12\x13\x41\x63\x46unDanmu.Im.Basic\x1a\x18\x41\x63\x63\x65ssPointsConfig.proto\x1a\x0fSdkOption.proto\"\xef\x03\n\x10RegisterResponse\x12\x43\n\x12\x61\x63\x63\x65ssPointsConfig\x18\x01 \x01(\x0b\x32\'.AcFunDanmu.Im.Basic.AccessPointsConfig\x12\x0f\n\x07sessKey\x18\x02 \x01(\x0c\x12\x12\n\ninstanceId\x18\x03 \x01(\x03\x12\x31\n\tsdkOption\x18\x04 \x01(\x0b\x32\x1e.AcFunDanmu.Im.Basic.SdkOption\x12G\n\x16\x61\x63\x63\x65ssPointsConfigIpv6\x18\x05 \x01(\x0b\x32\'.AcFunDanmu.Im.Basic.AccessPointsConfig\x12G\n\x16\x61\x63\x63\x65ssPointsConfigQuic\x18\x06 \x01(\x0b\x32\'.AcFunDanmu.Im.Basic.AccessPointsConfig\x12K\n\x1a\x61\x63\x63\x65ssPointsConfigQuicIpv6\x18\x07 \x01(\x0b\x32\'.AcFunDanmu.Im.Basic.AccessPointsConfig\x12\x18\n\x10\x63leanAccessPoint\x18\x08 \x01(\x08\x12\x45\n\x14\x61\x63\x63\x65ssPointsConfigWs\x18\t \x01(\x0b\x32\'.AcFunDanmu.Im.Basic.AccessPointsConfigb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'RegisterResponse_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _REGISTERRESPONSE._serialized_start=91
  _REGISTERRESPONSE._serialized_end=586
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: GroupJoinReqListResponse.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import GroupJoinReq_pb2 as GroupJoinReq__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1eGroupJoinReqListResponse.proto\x12\x1b\x41\x63\x46unDanmu.Im.Cloud.Message\x1a\x12GroupJoinReq.proto\"k\n\x18GroupJoinReqListResponse\x12?\n\x0cgroupJoinReq\x18\x01 \x03(\x0b\x32).AcFunDanmu.Im.Cloud.Message.GroupJoinReq\x12\x0e\n\x06offset\x18\x02 \x01(\tb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'GroupJoinReqListResponse_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _GROUPJOINREQLISTRESPONSE._serialized_start=83
  _GROUPJOINREQLISTRESPONSE._serialized_end=190
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: CommonStateSignalCurrentRedpackList.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import ZtLiveUserInfo_pb2 as ZtLiveUserInfo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n)CommonStateSignalCurrentRedpackList.proto\x12\nAcFunDanmu\x1a\x14ZtLiveUserInfo.proto\"\xe4\x03\n#CommonStateSignalCurrentRedpackList\x12I\n\x08redpacks\x18\x01 \x03(\x0b\x32\x37.AcFunDanmu.CommonStateSignalCurrentRedpackList.Redpack\x1a\xaf\x02\n\x07Redpack\x12*\n\x06sender\x18\x01 \x01(\x0b\x32\x1a.AcFunDanmu.ZtLiveUserInfo\x12[\n\rdisplayStatus\x18\x02 \x01(\x0e\x32\x44.AcFunDanmu.CommonStateSignalCurrentRedpackList.RedpackDisplayStatus\x12\x17\n\x0fgrabBeginTimeMs\x18\x03 \x01(\x03\x12\x1c\n\x14getTokenLatestTimeMs\x18\x04 \x01(\x03\x12\x11\n\tredPackId\x18\x05 \x01(\t\x12\x16\n\x0eredpackBizUnit\x18\x06 \x01(\t\x12\x15\n\rredpackAmount\x18\x07 \x01(\x03\x12\x17\n\x0fsettleBeginTime\x18\x08 \x01(\x03\x12\t\n\x01i\x18\t \x01(\x03\"@\n\x14RedpackDisplayStatus\x12\x08\n\x04SHOW\x10\x00\x12\r\n\tGET_TOKEN\x10\x01\x12\x08\n\x04GRAB\x10\x02\x12\x05\n\x01\x65\x10\x03\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'CommonStateSignalCurrentRedpackList_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _COMMONSTATESIGNALCURRENTREDPACKLIST._serialized_start=80
  _COMMONSTATESIGNALCURRENTREDPACKLIST._serialized_end=564
  _COMMONSTATESIGNALCURRENTREDPACKLIST_REDPACK._serialized_start=195
  _COMMONSTATESIGNALCURRENTREDPACKLIST_REDPACK._serialized_end=498
  _COMMONSTATESIGNALCURRENTREDPACKLIST_REDPACKDISPLAYSTATUS._serialized_start=500
  _COMMONSTATESIGNALCURRENTREDPACKLIST_REDPACKDISPLAYSTATUS._serialized_end=564
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ChatTargetType.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x14\x43hatTargetType.proto\x12\x15\x41\x63\x46unDanmu.Im.Message*\xa7\x01\n\x0e\x43hatTargetType\x12\x0c\n\x08\x43TT_USER\x10\x00\x12\x11\n\rCTT_CHAT_ROOM\x10\x02\x12\x19\n\x15\x43TT_MULTI_PLAYER_ROOM\x10\x03\x12\r\n\tCTT_GROUP\x10\x04\x12\x0f\n\x0b\x43TT_CHANNEL\x10\x05\x12\x11\n\rCTT_AGGREGATE\x10\x06\x12\x0b\n\x07\x43TT_B2C\x10\x07\x12\x19\n\x15\x43TT_SUB_BIZ_AGGREGATE\x10\x08\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ChatTargetType_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _CHATTARGETTYPE._serialized_start=48
  _CHATTARGETTYPE._serialized_end=215
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: CommonStateSignalPkStatistic.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import PkAudienceContributionInfo_pb2 as PkAudienceContributionInfo__pb2
import PkPlayerStatistic_pb2 as PkPlayerStatistic__pb2
import PkRoundInfo_pb2 as PkRoundInfo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"CommonStateSignalPkStatistic.proto\x12\nAcFunDanmu\x1a PkAudienceContributionInfo.proto\x1a\x17PkPlayerStatistic.proto\x1a\x11PkRoundInfo.proto\"\x82\x02\n\x1c\x43ommonStateSignalPkStatistic\x12\t\n\x01\x61\x18\x01 \x01(\t\x12\t\n\x01\x62\x18\x02 \x01(\x03\x12\t\n\x01\x63\x18\x03 \x01(\x03\x12\t\n\x01\x64\x18\x04 \x01(\x03\x12\t\n\x01\x65\x18\x05 \x01(\x08\x12\t\n\x01\x66\x18\x06 \x01(\x03\x12\t\n\x01g\x18\x07 \x01(\x03\x12\t\n\x01h\x18\x08 \x01(\x03\x12\x31\n\x01i\x18\t \x03(\x0b\x32&.AcFunDanmu.PkAudienceContributionInfo\x12(\n\x01j\x18\n \x03(\x0b\x32\x1d.AcFunDanmu.PkPlayerStatistic\x12\"\n\x01k\x18\x0b \x01(\x0b\x32\x17.AcFunDanmu.PkRoundInfo\x12\t\n\x01l\x18\x0c \x01(\x03\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'CommonStateSignalPkStatistic_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _COMMONSTATESIGNALPKSTATISTIC._serialized_start=129
  _COMMONSTATESIGNALPKSTATISTIC._serialized_end=387
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: GroupSettingRequest.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import GroupExtraDataUpdate_pb2 as GroupExtraDataUpdate__pb2
import GroupHeadUrlUpdate_pb2 as GroupHeadUrlUpdate__pb2
import GroupInviteNeedUserAgree_pb2 as GroupInviteNeedUserAgree__pb2
import GroupSettingAdminTransfer_pb2 as GroupSettingAdminTransfer__pb2
import GroupSettingBatchUpdate_pb2 as GroupSettingBatchUpdate__pb2
import GroupSettingDesc_pb2 as GroupSettingDesc__pb2
import GroupSettingInvitePermission_pb2 as GroupSettingInvitePermission__pb2
import GroupSettingJoinNeedPermission_pb2 as GroupSettingJoinNeedPermission__pb2
import GroupSettingMemberSilence_pb2 as GroupSettingMemberSilence__pb2
import GroupSettingMemberTempSilence_pb2 as GroupSettingMemberTempSilence__pb2
import GroupSettingRemindAllOnlyAdmin_pb2 as GroupSettingRemindAllOnlyAdmin__pb2
import GroupSettingRename_pb2 as GroupSettingRename__pb2
import GroupSettingUpdateOnlyAdmin_pb2 as GroupSettingUpdateOnlyAdmin__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x19GroupSettingRequest.proto\x12\x1b\x41\x63\x46unDanmu.Im.Cloud.Message\x1a\x1aGroupExtraDataUpdate.proto\x1a\x18GroupHeadUrlUpdate.proto\x1a\x1eGroupInviteNeedUserAgree.proto\x1a\x1fGroupSettingAdminTransfer.proto\x1a\x1dGroupSettingBatchUpdate.proto\x1a\x16GroupSettingDesc.proto\x1a\"GroupSettingInvitePermission.proto\x1a$GroupSettingJoinNeedPermission.proto\x1a\x1fGroupSettingMemberSilence.proto\x1a#GroupSettingMemberTempSilence.proto\x1a$GroupSettingRemindAllOnlyAdmin.proto\x1a\x18GroupSettingRename.proto\x1a!GroupSettingUpdateOnlyAdmin.proto\"\xf6\x08\n\x13GroupSettingRequest\x12\x41\n\x06rename\x18\x02 \x01(\x0b\x32/.AcFunDanmu.Im.Cloud.Message.GroupSettingRenameH\x00\x12=\n\x04\x64\x65sc\x18\x03 \x01(\x0b\x32-.AcFunDanmu.Im.Cloud.Message.GroupSettingDescH\x00\x12Y\n\x12joinNeedPermission\x18\x04 \x01(\x0b\x32;.AcFunDanmu.Im.Cloud.Message.GroupSettingJoinNeedPermissionH\x00\x12U\n\x10invitePermission\x18\x05 \x01(\x0b\x32\x39.AcFunDanmu.Im.Cloud.Message.GroupSettingInvitePermissionH\x00\x12U\n\x13groupMembersSilence\x18\x06 \x01(\x0b\x32\x36.AcFunDanmu.Im.Cloud.Message.GroupSettingMemberSilenceH\x00\x12T\n\x12groupAdminTransfer\x18\x07 \x01(\x0b\x32\x36.AcFunDanmu.Im.Cloud.Message.GroupSettingAdminTransferH\x00\x12Z\n\x16settingUpdateOnlyAdmin\x18\x08 \x01(\x0b\x32\x38.AcFunDanmu.Im.Cloud.Message.GroupSettingUpdateOnlyAdminH\x00\x12Y\n\x12remindAllOnlyAdmin\x18\t \x01(\x0b\x32;.AcFunDanmu.Im.Cloud.Message.GroupSettingRemindAllOnlyAdminH\x00\x12K\n\x0b\x62\x61tchUpdate\x18\n \x01(\x0b\x32\x34.AcFunDanmu.Im.Cloud.Message.GroupSettingBatchUpdateH\x00\x12\\\n\x16groupMemberTempSilence\x18\x0b \x01(\x0b\x32:.AcFunDanmu.Im.Cloud.Message.GroupSettingMemberTempSilenceH\x00\x12Q\n\x14groupExtraDataUpdate\x18\x0c \x01(\x0b\x32\x31.AcFunDanmu.Im.Cloud.Message.GroupExtraDataUpdateH\x00\x12M\n\x12groupHeadUrlUpdate\x18\r \x01(\x0b\x32/.AcFunDanmu.Im.Cloud.Message.GroupHeadUrlUpdateH\x00\x12Y\n\x18groupInviteNeedUserAgree\x18\x0e \x01(\x0b\x32\x35.AcFunDanmu.Im.Cloud.Message.GroupInviteNeedUserAgreeH\x00\x12\x0f\n\x07groupId\x18\x01 \x01(\tB\x0e\n\x0cGroupSettingb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'GroupSettingRequest_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _GROUPSETTINGREQUEST._serialized_start=476
  _GROUPSETTINGREQUEST._serialized_end=1618
# @@protoc_insertion_point(module_scope)



# coding=utf-8
import time
import json
import gzip
import proto
import base64
import filetype
from hashlib import md5
from Crypto import Random
from Crypto.Cipher import AES
from Crypto.Util.Padding import pad, unpad
from ..blackboxprotobuf import protobuf_to_json
from google.protobuf.json_format import MessageToJson
from google.protobuf.internal.python_message import GeneratedProtocolMessageType
from google.protobuf.internal.containers import RepeatedScalarFieldContainer
from google.protobuf.pyext._message import RepeatedScalarContainer
from dataclasses import dataclass
from .Im import PacketHeader_pb2, \
    UpstreamPayload_pb2, DownstreamPayload_pb2, \
    RegisterRequest_pb2, RegisterResponse_pb2, \
    ClientConfigGetRequest_pb2, ClientConfigGetResponse_pb2, \
    KeepAliveRequest_pb2, KeepAliveResponse_pb2, \
    GroupMemberListGetRequest_pb2, GroupMemberListGetResponse_pb2, \
    PullOldRequest_pb2, PullOldResponse_pb2, \
    SessionListResponse_pb2, SessionCreateRequest_pb2, \
    SessionCreateResponse_pb2, SessionRemoveRequest_pb2, \
    ErrorMessage_pb2, Message_pb2, Image_pb2
from .Live import ZtLiveCsCmd_pb2, \
    ZtLiveCsEnterRoom_pb2, ZtLiveCsHeartbeat_pb2, ZtLiveCsUserExit_pb2, \
    ZtLiveScMessage_pb2, acfun_live_pb2, \
    ZtLiveScActionSignal_pb2, \
    CommonActionSignalComment_pb2, CommonActionSignalLike_pb2, \
    CommonActionSignalUserEnterRoom_pb2, CommonActionSignalUserFollowAuthor_pb2, \
    CommonActionSignalGift_pb2, CommonActionSignalRichText_pb2, \
    ZtLiveScStateSignal_pb2, \
    CommonStateSignalDisplayInfo_pb2, CommonStateSignalTopUsers_pb2, \
    CommonStateSignalRecentComment_pb2, CommonStateSignalChatCall_pb2, \
    CommonStateSignalChatAccept_pb2, CommonStateSignalChatReady_pb2, \
    CommonStateSignalChatEnd_pb2, CommonStateSignalCurrentRedpackList_pb2, \
    CommonStateSignalAuthorChatCall_pb2, CommonStateSignalAuthorChatAccept_pb2, \
    CommonStateSignalAuthorChatReady_pb2, CommonStateSignalAuthorChatEnd_pb2, \
    CommonStateSignalAuthorChatChangeSoundConfig_pb2, \
    CommonStateSignalPKAccept_pb2, CommonStateSignalPKInvitation_pb2, \
    CommonStateSignalPKReady_pb2, CommonStateSignalPKSoundConfigChanged_pb2, \
    CommonStateSignalPkEnd_pb2, CommonStateSignalPkStatistic_pb2, \
    CommonStateSignalWishSheetCurrentState_pb2, \
    ZtLiveScNotifySignal_pb2, \
    CommonNotifySignalKickedOut_pb2, \
    CommonNotifySignalViolationAlert_pb2, \
    CommonNotifySignalLiveManagerState_pb2, \
    ZtLiveScStatusChanged_pb2, \
    ZtLiveScTicketInvalid_pb2

__author__ = 'dolacmeo'


def im_image_uploader(acer, to_uid: str, image_data: bytes) -> dict:
    md5_hex = md5(image_data).digest()
    head = {
        "Content-Type": filetype.guess_mime(image_data),
        "Content-MD5": base64.standard_b64encode(md5_hex),
        "file-type": filetype.guess_extension(image_data),
        "target": f"{to_uid}",
        "download-verify-type": "1",
    }
    param = {'kpn': "ACFUN_APP"}
    param = acer.update_token(param)
    post_req = acer.client.post("https://sixinpic.kuaishou.com/rest/v2/app/upload",
                                params=param, headers=head, data=image_data)
    return post_req.json()


def message_content_serialize(content: str):
    class MessageContent(proto.Message):
        content = proto.Field(proto.STRING, number=1)
    msg = MessageContent()
    msg.content = content.encode()
    return MessageContent.serialize(msg)


def proto_user_serialize(uid: int):
    class User(proto.Message):
        appId = proto.Field(proto.INT32, number=1)
        uid = proto.Field(proto.INT64, number=2)
    user = User()
    user.appId = 13
    user.uid = uid
    return User.serialize(user)


@dataclass(frozen=True)
class ProtosMap:
    command_rules = {
        "Basic.ClientConfigGet": ClientConfigGetResponse_pb2.ClientConfigGetResponse,
        "Basic.KeepAlive": KeepAliveResponse_pb2.KeepAliveResponse,
        "Message.Session": SessionListResponse_pb2.SessionListResponse,
        "Group.UserGroupList": GroupMemberListGetResponse_pb2.GroupMemberListGetResponse,
        "Message.PullOld": PullOldResponse_pb2.PullOldResponse,
        "Session.Create": SessionCreateResponse_pb2.SessionCreateResponse,
        "Message.Send": Message_pb2.Message,
        "Push.Message": Message_pb2.Message,
        "Message.SessionRemove": None,
        "Basic.Unregister": None,
    }
    live_acks = {
        "ZtLiveCsEnterRoomAck": ZtLiveCsEnterRoom_pb2.ZtLiveCsEnterRoomAck,
        "ZtLiveCsHeartbeatAck": ZtLiveCsHeartbeat_pb2.ZtLiveCsHeartbeatAck,
        "ZtLiveCsUserExitAck": ZtLiveCsUserExit_pb2.ZtLiveCsUserExitAck,
    }
    live_messages = {
        "ZtLiveScActionSignal": ZtLiveScActionSignal_pb2.ZtLiveScActionSignal,
        "ZtLiveScActionSignal.loader": {
            "CommonActionSignalComment": CommonActionSignalComment_pb2.CommonActionSignalComment,
            "CommonActionSignalLike": CommonActionSignalLike_pb2.CommonActionSignalLike,
            "CommonActionSignalUserEnterRoom": CommonActionSignalUserEnterRoom_pb2.CommonActionSignalUserEnterRoom,
            "CommonActionSignalUserFollowAuthor": CommonActionSignalUserFollowAuthor_pb2.CommonActionSignalUserFollowAuthor,
            "AcfunActionSignalThrowBanana": acfun_live_pb2.AcfunActionSignalThrowBanana,
            "CommonActionSignalGift": CommonActionSignalGift_pb2.CommonActionSignalGift,
            "CommonActionSignalRichText": CommonActionSignalRichText_pb2.CommonActionSignalRichText,
            "AcfunActionSignalJoinClub": acfun_live_pb2.AcfunActionSignalJoinClub,
        },
        "ZtLiveScStateSignal": ZtLiveScStateSignal_pb2.ZtLiveScStateSignal,
        "ZtLiveScStateSignal.loader": {
            "AcfunStateSignalDisplayInfo": acfun_live_pb2.AcfunStateSignalDisplayInfo,
            "CommonStateSignalDisplayInfo": CommonStateSignalDisplayInfo_pb2.CommonStateSignalDisplayInfo,
            "CommonStateSignalTopUsers": CommonStateSignalTopUsers_pb2.CommonStateSignalTopUsers,
            "CommonStateSignalRecentComment": CommonStateSignalRecentComment_pb2.CommonStateSignalRecentComment,
            "CommonStateSignalChatCall": CommonStateSignalChatCall_pb2.CommonStateSignalChatCall,
            "CommonStateSignalChatAccept": CommonStateSignalChatAccept_pb2.CommonStateSignalChatAccept,
            "CommonStateSignalChatReady": CommonStateSignalChatReady_pb2.CommonStateSignalChatReady,
            "CommonStateSignalChatEnd": CommonStateSignalChatEnd_pb2.CommonStateSignalChatEnd,
            "CommonStateSignalCurrentRedpackList": CommonStateSignalCurrentRedpackList_pb2.CommonStateSignalCurrentRedpackList,
            "CommonStateSignalAuthorChatCall": CommonStateSignalAuthorChatCall_pb2.CommonStateSignalAuthorChatCall,
            "CommonStateSignalAuthorChatAccept": CommonStateSignalAuthorChatAccept_pb2.CommonStateSignalAuthorChatAccept,
            "CommonStateSignalAuthorChatReady": CommonStateSignalAuthorChatReady_pb2.CommonStateSignalAuthorChatReady,
            "CommonStateSignalAuthorChatEnd": CommonStateSignalAuthorChatEnd_pb2.CommonStateSignalAuthorChatEnd,
            "CommonStateSignalAuthorChatChangeSoundConfig": CommonStateSignalAuthorChatChangeSoundConfig_pb2.CommonStateSignalAuthorChatChangeSoundConfig,
            "CommonStateSignalPKAccept": CommonStateSignalPKAccept_pb2.CommonStateSignalPKAccept,
            "CommonStateSignalPKInvitation": CommonStateSignalPKInvitation_pb2.CommonStateSignalPKInvitation,
            "CommonStateSignalPKReady": CommonStateSignalPKReady_pb2.CommonStateSignalPKReady,
            "CommonStateSignalPKSoundConfigChanged": CommonStateSignalPKSoundConfigChanged_pb2.CommonStateSignalPKSoundConfigChanged,
            "CommonStateSignalPkEnd": CommonStateSignalPkEnd_pb2.CommonStateSignalPkEnd,
            "CommonStateSignalPkStatistic": CommonStateSignalPkStatistic_pb2.CommonStateSignalPkStatistic,
            "CommonStateSignalWishSheetCurrentState": CommonStateSignalWishSheetCurrentState_pb2.CommonStateSignalWishSheetCurrentState,
        },
        "ZtLiveScNotifySignal": ZtLiveScNotifySignal_pb2.ZtLiveScNotifySignal,
        "ZtLiveScNotifySignal.loader": {
            "CommonNotifySignalKickedOut": CommonNotifySignalKickedOut_pb2.CommonNotifySignalKickedOut,
            "CommonNotifySignalViolationAlert": CommonNotifySignalViolationAlert_pb2.CommonNotifySignalViolationAlert,
            "CommonNotifySignalLiveManagerState": CommonNotifySignalLiveManagerState_pb2.CommonNotifySignalLiveManagerState,
        },
        "ZtLiveScStatusChanged": ZtLiveScStatusChanged_pb2.ZtLiveScStatusChanged,
        "ZtLiveScTicketInvalid": ZtLiveScTicketInvalid_pb2.ZtLiveScTicketInvalid,
    }


header_offset = 12
payload_offset = 16


class ProtosMaker:
    seqId = 0
    live_heartbeat = 0
    appId = 0
    instanceId = 0
    live_obj = None

    def __init__(self, acer, task_callback):
        self.acer = acer
        self.task = task_callback

    @staticmethod
    def aes_encrypt(key, payload):
        key = base64.standard_b64decode(key)
        iv = Random.new().read(AES.block_size)
        cipher = AES.new(key, AES.MODE_CBC, iv)
        payload = pad(payload, AES.block_size, 'pkcs7')
        result = cipher.encrypt(payload)
        return iv + result

    @staticmethod
    def aes_decrypt(key, data):
        key = base64.standard_b64decode(key)
        iv = data[:payload_offset]
        payload = data[payload_offset:]
        cipher = AES.new(key, AES.MODE_CBC, iv)
        result = cipher.decrypt(payload)
        return unpad(result, AES.block_size, 'pkcs7')

    def decode(self, message: bytes):
        # print(f"total length: {len(message)}")
        packet_header_len = int.from_bytes(message[4:8], byteorder='big')
        payload_len = int.from_bytes(message[8:12], byteorder='big')
        # print(f"packet_header_len: {packet_header_len} {message[4:8].hex()}")
        # print(f"payload_len: {payload_len} {message[8:12].hex()}")
        packet_header = PacketHeader_pb2.PacketHeader()
        header = message[header_offset:header_offset + packet_header_len]
        packet_header.ParseFromString(header)
        # print(packet_header)
        # print("=" * 40)
        payload_data = message[header_offset + packet_header_len:]
        # print(f"packet_header.encryptionMode: {packet_header.encryptionMode}")
        if packet_header.encryptionMode == 1:  # kEncryptionServiceToken
            decrypted_data = self.aes_decrypt(self.acer.tokens['ssecurity'], payload_data)
        elif packet_header.encryptionMode == 2:  # kEncryptionSessionKey
            decrypted_data = self.aes_decrypt(self.acer.tokens['sessKey'], payload_data)
        else:  # kEncryptionNone
            decrypted_data = payload_data
            stream_payload = ErrorMessage_pb2.ErrorMessage()
            stream_payload.ParseFromString(decrypted_data)
            print(stream_payload)
            raise BufferError(self.seqId, stream_payload.errorMessage)
        # decrypted_data = decrypted_data[:packet_header.decodedPayloadLen]
        # print(f"decrypted_data[{len(decrypted_data)}]: ", decrypted_data)
        # print(f"decrypted_data[b64]: {base64.standard_b64encode(decrypted_data)}")
        if self.seqId < 2:
            stream_payload = UpstreamPayload_pb2.UpstreamPayload()
        else:
            stream_payload = DownstreamPayload_pb2.DownstreamPayload()
        stream_payload.ParseFromString(decrypted_data)
        # print("#" * 40)
        # print(f"RecvCommand: {stream_payload.command}")
        # print("#" * 40)
        if stream_payload.errorCode:
            print(stream_payload)
            raise ValueError(f"[{stream_payload.errorCode}] {stream_payload.errorMsg}")
        command = stream_payload.command
        proto_class = ProtosMap.command_rules.get(command)
        if command == "Basic.Register":  # 初始化注册
            return self.BasicRegister_Response(packet_header, stream_payload)
        elif command == "Global.ZtLiveInteractive.CsCmd":  # 直播相关
            cmd_payload = ZtLiveCsCmd_pb2.ZtLiveCsCmdAck()
            cmd_payload.ParseFromString(stream_payload.payloadData)
            ack_type = cmd_payload.cmdAckType
            ack_payload = cmd_payload.payload
            if ack_type in ProtosMap.live_acks:
                return self.ZtLiveCsCmdAck_Response(ack_type, packet_header, ack_payload)
            if cmd_payload.errorCode:
                print(f"LiveError[{cmd_payload.errorCode}] {cmd_payload.errorMsg}")
        elif command == "Push.ZtLiveInteractive.Message":  # 直播推送
            live_push = ZtLiveScMessage_pb2.ZtLiveScMessage()
            live_push.ParseFromString(stream_payload.payloadData)
            msg_type = live_push.messageType
            msg_payload = gzip.decompress(live_push.payload) \
                if live_push.compressionType == 2 else live_push.payload
            if msg_type in ProtosMap.live_messages:
                return self.ZtLiveInteractive_Message(msg_type, packet_header, msg_payload)
            else:
                print(f"LiveMessageUnknown: {msg_type}\n{msg_payload}")
        elif proto_class is not None:  # 可解析消息
            return self.message_response(proto_class, packet_header, stream_payload)
        # 未知消息解析
        return self.unknown_response(packet_header, stream_payload)

    def BasicRegister_Response(self, packet_header, stream_payload):
        reg_resp = RegisterResponse_pb2.RegisterResponse()
        reg_resp.ParseFromString(stream_payload.payloadData)
        self.appId = packet_header.appId
        self.instanceId = packet_header.instanceId
        self.acer.tokens['sessKey'] = base64.standard_b64encode(reg_resp.sessKey)
        return packet_header.seqId, stream_payload.command, MessageToJson(reg_resp)

    def ZtLiveCsCmdAck_Response(self, ack_type, packet_header, ack_payload):
        if ack_type == "ZtLiveCsHeartbeatAck":
            self.task(*self.ZtLiveCsHeartbeat_Request())
        payload = ProtosMap.live_acks.get(ack_type)()
        payload.ParseFromString(ack_payload)
        return packet_header.seqId, f"LiveCmd.{ack_type}", json.loads(MessageToJson(payload))

    def ZtLiveInteractive_Message(self, msg_type, packet_header, msg_payload):
        self.task(*self.ZtLiveInteractiveMessage_Request())
        payload = ProtosMap.live_messages.get(msg_type)()
        payload.ParseFromString(msg_payload)
        those_msg = list()
        if msg_type in ["ZtLiveScActionSignal", "ZtLiveScStateSignal", "ZtLiveScNotifySignal"]:
            for item in payload.item:
                signal = item.signalType
                data = {"signal": f"{msg_type}.{signal}"}
                loader = ProtosMap.live_messages.get(f"{msg_type}.loader", {}).get(f"{signal}")
                if loader is not None:
                    loader = loader()
                    if isinstance(item.payload, (RepeatedScalarFieldContainer, RepeatedScalarContainer)):
                        data['payload'] = list()
                        for x in item.payload:
                            loader.ParseFromString(x)
                            data['payload'].append(json.loads(MessageToJson(loader)))
                    elif isinstance(item.payload, list):
                        data['payload'] = list()
                        for x in item.payload:
                            loader.ParseFromString(x)
                            data['payload'].append(json.loads(MessageToJson(loader)))
                    else:
                        loader.ParseFromString(item.payload)
                        data['payload'] = json.loads(MessageToJson(loader))
                those_msg.append(data)
        elif msg_type in ["ZtLiveScStatusChanged", "ZtLiveScTicketInvalid"]:
            those_msg = json.loads(MessageToJson(payload))
        else:
            those_msg = json.loads(MessageToJson(payload))
        if isinstance(those_msg, dict):
            those_msg = [those_msg]
        return packet_header.seqId, f"LivePush.{msg_type}", those_msg

    def message_response(self, proto_class, packet_header, stream_payload):
        payload = proto_class()
        payload.ParseFromString(stream_payload.payloadData)
        return packet_header.seqId, stream_payload.command, json.loads(MessageToJson(payload))

    def unknown_response(self, packet_header, stream_payload):
        message, typedef = protobuf_to_json(stream_payload.payloadData)
        if stream_payload.command not in ProtosMap.command_rules:
            print(f"[seqId:{packet_header.seqId}] {stream_payload.command}")
            print(typedef)
            print(message)
        payload_b64 = base64.standard_b64encode(stream_payload.payloadData)
        return packet_header.seqId, stream_payload.command, payload_b64

    def encode(self, key_n: int, command: str, payload, subBiz: [str, None] = None):
        self.seqId += 1
        # ####################   UpstreamPayload    ################# #
        upstream_payload = UpstreamPayload_pb2.UpstreamPayload()
        upstream_payload.command = command
        upstream_payload.seqId = self.seqId
        upstream_payload.retryCount = 1
        if hasattr(payload, "DESCRIPTOR"):  # protos_class has attr "DESCRIPTOR"
            upstream_payload.payloadData = payload.SerializeToString()
        elif isinstance(payload, bytes):
            upstream_payload.payloadData = payload
        if isinstance(subBiz, (str, bytes)):
            upstream_payload.subBiz = subBiz
        payload_body = upstream_payload.SerializeToString()
        # ####################      Encoding        ################# #
        token_info = PacketHeader_pb2.TokenInfo__pb2.TokenInfo()
        token_info.tokenType = 1
        if self.acer.is_logined:
            token_info.token = self.acer.tokens['api_st'].encode()
        else:
            token_info.token = self.acer.tokens['visitor_st'].encode()
        header = PacketHeader_pb2.PacketHeader()
        header.appId = self.appId
        header.instanceId = self.instanceId
        header.uid = self.acer.uid
        payload_len = len(payload_body)
        encrypted = payload_body
        if key_n in [1, 2]:
            key = self.acer.tokens['ssecurity'] if key_n == 1 else self.acer.tokens['sessKey']
            encrypted = self.aes_encrypt(key, payload_body)
        header.decodedPayloadLen = payload_len
        header.encryptionMode = key_n
        header.tokenInfo.CopyFrom(token_info)
        header.seqId = self.seqId
        header.kpn = b"ACFUN_APP"
        header_payload = header.SerializeToString()
        return self.seqId, command, b"".join([
            bytes.fromhex("abcd0001"),
            len(header_payload).to_bytes(4, "big"),
            len(encrypted).to_bytes(4, "big"),
            header_payload,
            encrypted
        ])

    def BasicRegister_Request(self):
        payload = RegisterRequest_pb2.RegisterRequest()
        app_info = RegisterRequest_pb2.AppInfo__pb2.AppInfo()
        app_info.sdkVersion = "kwai-acfun-live-link"
        app_info.linkVersion = "2.13.8"
        payload.appInfo.CopyFrom(app_info)
        device_info = RegisterRequest_pb2.DeviceInfo__pb2.DeviceInfo()
        device_info.platformType = 9
        device_info.deviceModel = "h5"
        device_info.deviceId = self.acer.did
        payload.deviceInfo.CopyFrom(device_info)
        payload.presenceStatus = 1
        payload.appActiveStatus = 1
        ztcommon_info = RegisterRequest_pb2.ZtCommonInfo__pb2.ZtCommonInfo()
        ztcommon_info.kpn = "ACFUN_APP"
        ztcommon_info.kpf = "PC_WEB"
        ztcommon_info.uid = self.acer.uid
        ztcommon_info.did = self.acer.did
        payload.instanceId = self.instanceId
        payload.ztCommonInfo.CopyFrom(ztcommon_info)
        return self.encode(1, "Basic.Register", payload, "mainApp")

    def ClientConfigGet_Request(self):
        payload = ClientConfigGetRequest_pb2.ClientConfigGetRequest()
        payload.version = 0
        return self.encode(2, "Basic.ClientConfigGet", payload)

    def KeepAlive_Request(self):
        payload = KeepAliveRequest_pb2.KeepAliveRequest()
        payload.presenceStatus = 1
        payload.appActiveStatus = 1
        payload.keepaliveIntervalSec = 120
        return self.encode(2, "Basic.KeepAlive", payload)

    def Unregister_Request(self):
        return self.encode(2, "Basic.Unregister", bytes())

    def BasicPing_Request(self):
        return self.encode(2, "Basic.Ping", bytes())

    def MessageSession_Request(self):
        return self.encode(2, "Message.Session", bytes([16, 0]))

    def SessionCreate_Request(self, target_uid: int):
        payload = SessionCreateRequest_pb2.SessionCreateRequest()
        chat = SessionCreateRequest_pb2.ChatTarget__pb2.ChatTarget()
        chat.targetId = f"{target_uid}"
        chat.targetType = 0
        payload.chatTarget.CopyFrom(chat)
        return self.encode(2, "Session.Create", payload)

    def SessionRemove_Request(self, target_uid: int):
        payload = SessionRemoveRequest_pb2.SessionRemoveRequest()
        payload.targetId = target_uid
        payload.strTargetId = f"{target_uid}"
        return self.encode(2, "Message.SessionRemove", payload)

    def UserGroupList_Request(self):
        payload = GroupMemberListGetRequest_pb2.GroupMemberListGetRequest()
        payload.groupId = b"0"
        sync_cookie_payload = GroupMemberListGetRequest_pb2.SyncCookie__pb2.SyncCookie()
        sync_cookie_payload.syncOffset = -1
        payload.syncCookie.CopyFrom(sync_cookie_payload)
        return self.encode(2, "Group.UserGroupList", payload)

    def MessagePullOld_Request(self, uid: int, minSeq: int, maxSeq: int, count: int = 10):
        payload = PullOldRequest_pb2.PullOldRequest()
        payload.target.ParseFromString(proto_user_serialize(uid))
        payload.minSeq = minSeq
        payload.maxSeq = maxSeq
        payload.count = count
        return self.encode(2, "Message.PullOld", payload)

    def Message_Request(self, target_uid: int, content: bytes, content_type: int = 0):
        payload = Message_pb2.Message()
        # payload.seqId = int(f"{time.time():.0f}{1:0>6}")
        payload.clientSeqId = int(f"{time.time():.0f}{1:0>6}")
        payload.timestampMs = int(f"{time.time():.0f}{1:0>3}")
        payload.fromUser.ParseFromString(proto_user_serialize(self.acer.uid))
        payload.targetId = target_uid
        payload.toUser.ParseFromString(proto_user_serialize(target_uid))
        payload.contentType = content_type
        payload.content = content
        payload.strTargetId = str(target_uid)
        return self.encode(2, "Message.Send", payload)

    def MessageContent_Request(self, target_uid: int, content: str):
        byte_content = message_content_serialize(content)
        return self.Message_Request(target_uid, byte_content, 0)

    def MessageImage_Request(self, target_uid: int, image_data: bytes):
        uploader_resp = im_image_uploader(self.acer, to_uid=f"{target_uid}", image_data=image_data)
        ks_uri = uploader_resp.get('uri')
        if ks_uri is None:
            print(uploader_resp)
            raise ValueError(uploader_resp['error_msg'])
        img_payload = Image_pb2.Image()
        img_payload.uri = ks_uri
        img_payload.width = 300
        img_payload.height = 300
        img_payload.contentLength = len(image_data)
        byte_content = img_payload.SerializeToString()
        return self.Message_Request(target_uid, byte_content, 1)

    def ZtLiveInteractive_CsCmd(self, cmd: str, cmd_payload):
        if self.live_obj is None:
            raise ValueError(f"Need Enter Live Rome First!!!\nUSE: ZtLiveCsEnterRoom_Request(uid)")
        payload = ZtLiveCsCmd_pb2.ZtLiveCsCmd()
        payload.cmdType = cmd
        payload.payload = cmd_payload.SerializeToString()
        payload.liveId = self.live_obj.liveId
        payload.ticket = self.live_obj.availableTickets[0]
        return self.encode(2, "Global.ZtLiveInteractive.CsCmd", payload, "mainApp")

    def ZtLiveCsEnterRoom_Request(self, live_obj):
        self.live_obj = live_obj
        enter_room_payload = ZtLiveCsEnterRoom_pb2.ZtLiveCsEnterRoom()
        enter_room_payload.isAuthor = self.acer.uid == live_obj.uid
        # enter_room_payload.reconnectCount = 0
        # enter_room_payload.lastErrorCode = 0
        enter_room_payload.enterRoomAttach = live_obj.enterRoomAttach
        enter_room_payload.clientLiveSdkVersion = "kwai-acfun-live-link"
        return self.ZtLiveInteractive_CsCmd("ZtLiveCsEnterRoom", enter_room_payload)

    def ZtLiveCsHeartbeat_Request(self):
        self.task(*self.ZtLiveInteractiveMessage_Request())
        self.live_heartbeat += 1
        if self.live_heartbeat % 5 == 4:
            # 即启动Heartbeat定时器后每50秒，发送KeepAliveRequest，SeqId + 1
            self.task(*self.KeepAlive_Request())
        time.sleep(4)
        heartbeat_payload = ZtLiveCsHeartbeat_pb2.ZtLiveCsHeartbeat()
        heartbeat_payload.clientTimestampMs = int(time.time()) * 1000
        heartbeat_payload.sequence = self.live_heartbeat
        return self.ZtLiveInteractive_CsCmd("ZtLiveCsHeartbeat", heartbeat_payload)

    def ZtLiveInteractiveMessage_Request(self):
        return self.encode(2, "Push.ZtLiveInteractive.Message", bytes(), "mainApp")



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: SessionFolderAddRefResponse.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import SessionReference_pb2 as SessionReference__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!SessionFolderAddRefResponse.proto\x12!AcFunDanmu.Im.Cloud.SessionFolder\x1a\x16SessionReference.proto\"l\n\x1bSessionFolderAddRefResponse\x12M\n\x10sessionReference\x18\x01 \x03(\x0b\x32\x33.AcFunDanmu.Im.Cloud.SessionFolder.SessionReferenceb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'SessionFolderAddRefResponse_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _SESSIONFOLDERADDREFRESPONSE._serialized_start=96
  _SESSIONFOLDERADDREFRESPONSE._serialized_end=204
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: UserGroupInfo.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import GroupInfo_pb2 as GroupInfo__pb2
import GroupMember_pb2 as GroupMember__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x13UserGroupInfo.proto\x12\x1b\x41\x63\x46unDanmu.Im.Cloud.Message\x1a\x0fGroupInfo.proto\x1a\x11GroupMember.proto\"\x89\x01\n\rUserGroupInfo\x12\x39\n\tgroupInfo\x18\x01 \x01(\x0b\x32&.AcFunDanmu.Im.Cloud.Message.GroupInfo\x12=\n\x0bgroupMember\x18\x02 \x01(\x0b\x32(.AcFunDanmu.Im.Cloud.Message.GroupMemberb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'UserGroupInfo_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _USERGROUPINFO._serialized_start=89
  _USERGROUPINFO._serialized_end=226
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: CsQuestionMessageContent.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1e\x43sQuestionMessageContent.proto\x12\x1b\x41\x63\x46unDanmu.Im.Cloud.Message\"\xf4\x02\n\x18\x43sQuestionMessageContent\x12\r\n\x05title\x18\x01 \x01(\t\x12R\n\x08question\x18\x02 \x03(\x0b\x32@.AcFunDanmu.Im.Cloud.Message.CsQuestionMessageContent.CsQuestion\x12\x12\n\nbizContent\x18\x03 \x01(\x0c\x1a\xe0\x01\n\nCsQuestion\x12\x12\n\nquestionId\x18\x01 \x01(\x03\x12\x0c\n\x04text\x18\x02 \x01(\t\x12\x11\n\tactionUrl\x18\x03 \x01(\t\x12_\n\nactionType\x18\x04 \x01(\x0e\x32K.AcFunDanmu.Im.Cloud.Message.CsQuestionMessageContent.CsQuestion.ActionType\"<\n\nActionType\x12\x0e\n\nAT_UNKNOWN\x10\x00\x12\x0c\n\x08REDIRECT\x10\x01\x12\x10\n\x0cSEND_MESSAGE\x10\x02\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'CsQuestionMessageContent_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _CSQUESTIONMESSAGECONTENT._serialized_start=64
  _CSQUESTIONMESSAGECONTENT._serialized_end=436
  _CSQUESTIONMESSAGECONTENT_CSQUESTION._serialized_start=212
  _CSQUESTIONMESSAGECONTENT_CSQUESTION._serialized_end=436
  _CSQUESTIONMESSAGECONTENT_CSQUESTION_ACTIONTYPE._serialized_start=376
  _CSQUESTIONMESSAGECONTENT_CSQUESTION_ACTIONTYPE._serialized_end=436
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ImageTextMessage.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x16ImageTextMessage.proto\x12\x15\x41\x63\x46unDanmu.Im.Message\"\x7f\n\x10ImageTextMessage\x12\r\n\x05title\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x10\n\x08imageUrl\x18\x03 \x01(\t\x12\x11\n\tactionUrl\x18\x04 \x01(\t\x12\r\n\x05width\x18\x05 \x01(\x05\x12\x13\n\x0b\x61spectRatio\x18\x06 \x01(\x02\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ImageTextMessage_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _IMAGETEXTMESSAGE._serialized_start=49
  _IMAGETEXTMESSAGE._serialized_end=176
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: GroupBasicInfo.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import ForbiddenState_pb2 as ForbiddenState__pb2
import GroupLabel_pb2 as GroupLabel__pb2
import GroupStatus_pb2 as GroupStatus__pb2
import GroupType_pb2 as GroupType__pb2
import InvitePermissionType_pb2 as InvitePermissionType__pb2
import JoinNeedPermissionType_pb2 as JoinNeedPermissionType__pb2
import Location_pb2 as Location__pb2
import MultiForbiddenState_pb2 as MultiForbiddenState__pb2
import User_pb2 as User__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x14GroupBasicInfo.proto\x12\x1b\x41\x63\x46unDanmu.Im.Cloud.Message\x1a\x14\x46orbiddenState.proto\x1a\x10GroupLabel.proto\x1a\x11GroupStatus.proto\x1a\x0fGroupType.proto\x1a\x1aInvitePermissionType.proto\x1a\x1cJoinNeedPermissionType.proto\x1a\x0eLocation.proto\x1a\x19MultiForbiddenState.proto\x1a\nUser.proto\"\xc4\t\n\x0eGroupBasicInfo\x12\x0f\n\x07groupId\x18\x01 \x01(\t\x12\x11\n\tgroupName\x18\x02 \x01(\t\x12(\n\x05\x61\x64min\x18\x03 \x01(\x0b\x32\x19.AcFunDanmu.Im.Basic.User\x12=\n\x0bgroupStatus\x18\x04 \x01(\x0e\x32(.AcFunDanmu.Im.Cloud.Message.GroupStatus\x12\x13\n\x0b\x64\x65scription\x18\x05 \x01(\t\x12O\n\x12joinNeedPermission\x18\x06 \x01(\x0e\x32\x33.AcFunDanmu.Im.Cloud.Message.JoinNeedPermissionType\x12\x12\n\ncreateTime\x18\x07 \x01(\x03\x12\x12\n\nupdateTime\x18\x08 \x01(\x03\x12\x39\n\tgroupType\x18\t \x01(\x0e\x32&.AcFunDanmu.Im.Cloud.Message.GroupType\x12\x43\n\x0e\x66orbiddenState\x18\n \x01(\x0e\x32+.AcFunDanmu.Im.Cloud.Message.ForbiddenState\x12O\n\x14invitePermissionType\x18\x0b \x01(\x0e\x32\x31.AcFunDanmu.Im.Cloud.Message.InvitePermissionType\x12\x12\n\nbizDefCode\x18\x0c \x01(\x05\x12\x18\n\x10\x64\x65\x66\x61ultGroupName\x18\r \x01(\t\x12\r\n\x05\x65xtra\x18\x0e \x01(\t\x12\x11\n\tisMuteAll\x18\x0f \x01(\x08\x12#\n\x1bonlyAdminUpdateGroupSetting\x18\x10 \x01(\x08\x12\x1a\n\x12onlyAdminRemindAll\x18\x11 \x01(\x08\x12/\n\x0cusersCanTalk\x18\x12 \x03(\x0b\x32\x19.AcFunDanmu.Im.Basic.User\x12\x33\n\x10usersKeepSilence\x18\x13 \x03(\x0b\x32\x19.AcFunDanmu.Im.Basic.User\x12\x14\n\x0cgroupHeadUrl\x18\x14 \x01(\t\x12\x37\n\x08location\x18\x15 \x01(\x0b\x32%.AcFunDanmu.Im.Cloud.Message.Location\x12\x0b\n\x03tag\x18\x16 \x01(\t\x12\x13\n\x0bgroupNumber\x18\x17 \x01(\t\x12\x14\n\x0cintroduction\x18\x18 \x01(\t\x12\x16\n\x0emaxMemberCount\x18\x19 \x01(\x05\x12M\n\x13multiForbiddenState\x18\x1a \x03(\x0e\x32\x30.AcFunDanmu.Im.Cloud.Message.MultiForbiddenState\x12\x17\n\x0fmaxManagerCount\x18\x1b \x01(\x05\x12\x36\n\x05label\x18\x1c \x03(\x0b\x32\'.AcFunDanmu.Im.Cloud.Message.GroupLabel\x12\x19\n\x11groupExtraSetting\x18\x1d \x01(\x03\x12 \n\x18groupInviteNeedUserAgree\x18\x1e \x01(\x08\x12\x1e\n\x16historyMessagesVisible\x18\x1f \x01(\x08\x12\x1a\n\x12groupDismissBanned\x18  \x01(\x08\x12\x17\n\x0fgroupQuitBanned\x18! \x01(\x08\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'GroupBasicInfo_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _GROUPBASICINFO._serialized_start=243
  _GROUPBASICINFO._serialized_end=1463
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: GroupFindType.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x13GroupFindType.proto\x12\x1b\x41\x63\x46unDanmu.Im.Cloud.Message*\xa6\x01\n\rGroupFindType\x12\x0e\n\nBY_UNKNOWN\x10\x00\x12\t\n\x05\x42Y_ID\x10\x01\x12\x0b\n\x07\x42Y_NAME\x10\x02\x12\x0e\n\nBY_QR_CODE\x10\x03\x12\x0b\n\x07\x42Y_CARD\x10\x04\x12\x11\n\rBY_INVITATION\x10\x05\x12\x11\n\rBY_SHARE_LINK\x10\x06\x12\x0e\n\nBY_PROFILE\x10\x07\x12\r\n\tBY_SEARCH\x10\x08\x12\x0b\n\x07\x42Y_NEWS\x10\tb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'GroupFindType_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _GROUPFINDTYPE._serialized_start=53
  _GROUPFINDTYPE._serialized_end=219
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: CommonActionSignalGift.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import ZtLiveUserInfo_pb2 as ZtLiveUserInfo__pb2
import ZtDrawGiftInfo_pb2 as ZtDrawGiftInfo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1c\x43ommonActionSignalGift.proto\x12\nAcFunDanmu\x1a\x14ZtLiveUserInfo.proto\x1a\x14ZtDrawGiftInfo.proto\"\x9c\x02\n\x16\x43ommonActionSignalGift\x12,\n\x08userInfo\x18\x01 \x01(\x0b\x32\x1a.AcFunDanmu.ZtLiveUserInfo\x12\x12\n\nsendTimeMs\x18\x02 \x01(\x03\x12\x0e\n\x06giftId\x18\x03 \x01(\x03\x12\x11\n\tbatchSize\x18\x04 \x01(\x05\x12\x12\n\ncomboCount\x18\x05 \x01(\x05\x12\x0c\n\x04rank\x18\x06 \x01(\x03\x12\x10\n\x08\x63omboKey\x18\x07 \x01(\t\x12\x1d\n\x15slotDisplayDurationMs\x18\x08 \x01(\x03\x12\x18\n\x10\x65xpireDurationMs\x18\t \x01(\x03\x12\x30\n\x0c\x64rawGiftInfo\x18\n \x01(\x0b\x32\x1a.AcFunDanmu.ZtDrawGiftInfob\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'CommonActionSignalGift_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _COMMONACTIONSIGNALGIFT._serialized_start=89
  _COMMONACTIONSIGNALGIFT._serialized_end=373
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: Invitation.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import InvitationOperator_pb2 as InvitationOperator__pb2
import JoinRequestStatus_pb2 as JoinRequestStatus__pb2
import User_pb2 as User__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x10Invitation.proto\x12\x1b\x41\x63\x46unDanmu.Im.Cloud.Message\x1a\x18InvitationOperator.proto\x1a\x17JoinRequestStatus.proto\x1a\nUser.proto\"\xdc\x02\n\nInvitation\x12\x0e\n\x06reqSeq\x18\x01 \x01(\x03\x12\x0f\n\x07groupId\x18\x02 \x01(\t\x12.\n\x0brequestUser\x18\x03 \x01(\x0b\x32\x19.AcFunDanmu.Im.Basic.User\x12\x11\n\tgroupName\x18\x04 \x01(\t\x12\x10\n\x08\x66indType\x18\x05 \x01(\x05\x12\x13\n\x0b\x64\x65scContent\x18\x06 \x01(\t\x12\x15\n\rauditComments\x18\x07 \x01(\t\x12>\n\x06status\x18\x08 \x01(\x0e\x32..AcFunDanmu.Im.Cloud.Message.JoinRequestStatus\x12\x41\n\x08operator\x18\t \x01(\x0b\x32/.AcFunDanmu.Im.Cloud.Message.InvitationOperator\x12\x13\n\x0bgroupNumber\x18\n \x01(\t\x12\x14\n\x0cgroupHeadUrl\x18\x0b \x01(\tb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'Invitation_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _INVITATION._serialized_start=113
  _INVITATION._serialized_end=461
# @@protoc_insertion_point(module_scope)



# coding=utf-8
from .acws import AcWebSocket

__author__ = 'dolacmeo'


class AcIM(AcWebSocket):

    def __init__(self, acer, ws_links: [list, None] = None):
        super().__init__(acer, ws_links)

    def reader(self, seq_id: int, command, result):
        pass

    def im_get_sessions(self):
        message = self.protos.MessageSession_Request()
        return self.task(*message)

    def im_session_start(self, uid: int):
        message = self.protos.SessionCreate_Request(uid)
        return self.task(*message)

    def im_session_close(self, uid: int):
        message = self.protos.SessionRemove_Request(uid)
        return self.task(*message)

    def im_pull_message(self, uid: int, minSeq: int, maxSeq: int, count: int = 10):
        message = self.protos.MessagePullOld_Request(uid, minSeq, maxSeq, count)
        return self.task(*message)

    def im_send(self, uid: int, content: str):
        message = self.protos.MessageContent_Request(uid, content)
        return self.task(*message)

    def im_send_image(self, uid: int, image_data: bytes):
        message = self.protos.MessageImage_Request(uid, image_data)
        return self.task(*message)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: CommonStateSignalWishSheetCurrentState.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n,CommonStateSignalWishSheetCurrentState.proto\x12\nAcFunDanmu\"\xd9\x01\n&CommonStateSignalWishSheetCurrentState\x12\t\n\x01\x61\x18\x01 \x01(\t\x12N\n\x01\x62\x18\x02 \x03(\x0b\x32\x43.AcFunDanmu.CommonStateSignalWishSheetCurrentState.WishCurrentState\x1aT\n\x10WishCurrentState\x12\t\n\x01\x61\x18\x01 \x01(\t\x12\t\n\x01\x62\x18\x02 \x01(\x03\x12\t\n\x01\x63\x18\x03 \x01(\x03\x12\t\n\x01\x64\x18\x04 \x01(\x03\x12\t\n\x01\x65\x18\x05 \x01(\t\x12\t\n\x01\x66\x18\x06 \x01(\tb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'CommonStateSignalWishSheetCurrentState_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _COMMONSTATESIGNALWISHSHEETCURRENTSTATE._serialized_start=61
  _COMMONSTATESIGNALWISHSHEETCURRENTSTATE._serialized_end=278
  _COMMONSTATESIGNALWISHSHEETCURRENTSTATE_WISHCURRENTSTATE._serialized_start=194
  _COMMONSTATESIGNALWISHSHEETCURRENTSTATE_WISHCURRENTSTATE._serialized_end=278
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: UserLoginDeviceInfo.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x19UserLoginDeviceInfo.proto\x12\x1b\x41\x63\x46unDanmu.Im.Cloud.Profile\"s\n\x13UserLoginDeviceInfo\x12\x10\n\x08\x64\x65viceId\x18\x01 \x01(\t\x12\x12\n\ndeviceName\x18\x02 \x01(\t\x12\x0b\n\x03kpf\x18\x03 \x01(\t\x12\x16\n\x0elastOnlineTime\x18\x04 \x01(\x03\x12\x11\n\tbizStatus\x18\x05 \x01(\x05\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'UserLoginDeviceInfo_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _USERLOGINDEVICEINFO._serialized_start=58
  _USERLOGINDEVICEINFO._serialized_end=173
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: Message.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import Reminder_pb2 as Reminder__pb2
import User_pb2 as User__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\rMessage.proto\x12\x15\x41\x63\x46unDanmu.Im.Message\x1a\x0eReminder.proto\x1a\nUser.proto\"\xd8\x05\n\x07Message\x12\r\n\x05seqId\x18\x01 \x01(\x03\x12\x13\n\x0b\x63lientSeqId\x18\x02 \x01(\x03\x12\x13\n\x0btimestampMs\x18\x03 \x01(\x03\x12+\n\x08\x66romUser\x18\x04 \x01(\x0b\x32\x19.AcFunDanmu.Im.Basic.User\x12\x10\n\x08targetId\x18\x05 \x01(\x03\x12)\n\x06toUser\x18\x06 \x01(\x0b\x32\x19.AcFunDanmu.Im.Basic.User\x12\r\n\x05title\x18\x07 \x01(\t\x12\x13\n\x0b\x63ontentType\x18\x08 \x01(\x05\x12\x0f\n\x07\x63ontent\x18\t \x01(\x0c\x12\x12\n\nbackupTips\x18\n \x01(\t\x12,\n\treceivers\x18\x0b \x03(\x0b\x32\x19.AcFunDanmu.Im.Basic.User\x12\x16\n\x0enotCountUnread\x18\x0c \x01(\x08\x12\x17\n\x0fsessionPriority\x18\r \x01(\x05\x12\x19\n\x11sessionCategoryId\x18\x0e \x01(\x05\x12\x1a\n\x12sessionAccountType\x18\x0f \x01(\x05\x12\x1c\n\x14notAutoCreateSession\x18\x10 \x01(\x08\x12\x18\n\x10userRelationship\x18\x11 \x01(\x05\x12\x13\n\x0bstrTargetId\x18\x12 \x01(\t\x12\x33\n\x10\x65xcludeReceivers\x18\x13 \x03(\x0b\x32\x19.AcFunDanmu.Im.Basic.User\x12\x12\n\nmarkDelete\x18\x14 \x01(\x08\x12\x31\n\x08reminder\x18\x15 \x01(\x0b\x32\x1f.AcFunDanmu.Im.Message.Reminder\x12\r\n\x05\x65xtra\x18\x16 \x01(\x0c\x12\x17\n\x0freceiptRequired\x18\x17 \x01(\x08\x12/\n\x0crealFromUser\x18\x18 \x01(\x0b\x32\x19.AcFunDanmu.Im.Basic.User\x12\x0f\n\x07\x63sExtra\x18\x19 \x01(\x0c\x12\x18\n\x10sessionInvisible\x18\x1a \x01(\x08\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'Message_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _MESSAGE._serialized_start=69
  _MESSAGE._serialized_end=797
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: CommonStateSignalRecentComment.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import CommonActionSignalComment_pb2 as CommonActionSignalComment__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$CommonStateSignalRecentComment.proto\x12\nAcFunDanmu\x1a\x1f\x43ommonActionSignalComment.proto\"X\n\x1e\x43ommonStateSignalRecentComment\x12\x36\n\x07\x63omment\x18\x01 \x03(\x0b\x32%.AcFunDanmu.CommonActionSignalCommentb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'CommonStateSignalRecentComment_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _COMMONSTATESIGNALRECENTCOMMENT._serialized_start=85
  _COMMONSTATESIGNALRECENTCOMMENT._serialized_end=173
# @@protoc_insertion_point(module_scope)



# coding=utf-8
import time
import random
import threading
import websocket
from .models.utils import ProtosMaker

__author__ = 'dolacmeo'

websocket_links = [
    # "wss://klink-newproduct-ws1.kwaizt.com",
    "wss://klink-newproduct-ws2.kwaizt.com",
    "wss://klink-newproduct-ws3.kwaizt.com",
    # "wss://klink-newproduct-ws1.kuaishouzt.com",
    "wss://klink-newproduct-ws2.kuaishouzt.com",
    "wss://klink-newproduct-ws3.kuaishouzt.com",
]


class AcWebSocket:
    ws_link = None
    _main_thread = None
    tasks = dict()
    commands = dict()
    is_register_done = False
    is_close = True

    def __init__(self, acer, ws_links: [list, None] = None):
        # websocket.enableTrace(True)
        self.acer = acer
        self.ws_link = random.choice(websocket_links if ws_links is None else ws_links)
        self.protos = ProtosMaker(self.acer, self.task)
        self.ws = websocket.WebSocketApp(
            url=self.ws_link,
            on_open=self._register,
            on_message=self._message,
            on_error=self._on_error,
            on_close=self._on_close,
            on_ping=self._keep_alive_request,
            on_pong=self._keep_alive_response,
        )
        self.listenner = dict()

    def run(self):
        def _run():
            self.ws.run_forever(
                ping_interval=10, ping_timeout=5,
                skip_utf8_validation=True,
                origin="live.acfun.cn",
            )
        self._main_thread = threading.Thread(target=_run)
        self._main_thread.start()
        self.is_close = False
        return self

    def task(self, seq_id: int, command, content):
        if self.is_close is True:
            return False
        if f"{seq_id}" not in self.tasks:
            self.tasks[f"{seq_id}"] = dict()
        self.tasks[f"{seq_id}"]["send"] = {"command": command, "content": content, "time": time.time()}
        if command not in self.commands:
            self.commands[command] = []
        self.commands[command].append({"seqId": f"{seq_id}", "way": "send", "time": time.time()})
        self.ws.send(content)

    def ans_task(self, seq_id: int, command, result):
        if command == 'Basic.Register':
            self.task(*self.protos.ClientConfigGet_Request())
            self.is_register_done = True
        elif command == 'Basic.ClientConfigGet':
            self.task(*self.protos.KeepAlive_Request())
            self.protos.client_config = result
        elif command == 'Basic.KeepAlive':
            pass
        self.reader(seq_id, command, result)

    def reader(self, seq_id: int, command, result):
        print(f"{command=}")

    def _register(self, ws):
        self.task(*self.protos.BasicRegister_Request())

    def _message(self, ws, message):
        self.ans_task(*self.protos.decode(message))

    def _keep_alive_request(self, ws, message):
        self.task(*self.protos.BasicPing_Request())

    def _keep_alive_response(self, ws, message):
        if self.is_register_done:
            self.task(*self.protos.KeepAlive_Request())

    def _on_close(self, ws, close_status_code, close_msg):
        # Because on_close was triggered, we know the opcode = 8
        # if close_status_code or close_msg:
        #     print("on_close args:")
        #     print(f"  close status code: {close_status_code}")
        #     print(f"  close message    : {close_msg}")
        # print(">>>>>>>> AcWebsocket  CLOSED <<<<<<<<<")
        pass

    def _on_error(self, ws, e):
        print(f"ONERROR: {e=}")
        self.close()

    def close(self):
        self.task(*self.protos.Unregister_Request())
        self.is_close = True
        self.ws.close()

    def restart(self):
        self.close()
        self.run()



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ZtLiveScMessage.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x15ZtLiveScMessage.proto\x12\nAcFunDanmu\"\xec\x01\n\x0fZtLiveScMessage\x12\x13\n\x0bmessageType\x18\x01 \x01(\t\x12\x44\n\x0f\x63ompressionType\x18\x02 \x01(\x0e\x32+.AcFunDanmu.ZtLiveScMessage.CompressionType\x12\x0f\n\x07payload\x18\x03 \x01(\x0c\x12\x0e\n\x06liveId\x18\x04 \x01(\t\x12\x0e\n\x06ticket\x18\x05 \x01(\t\x12\x19\n\x11serverTimestampMs\x18\x06 \x01(\x03\"2\n\x0f\x43ompressionType\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x08\n\x04NONE\x10\x01\x12\x08\n\x04GZIP\x10\x02\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ZtLiveScMessage_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _ZTLIVESCMESSAGE._serialized_start=38
  _ZTLIVESCMESSAGE._serialized_end=274
  _ZTLIVESCMESSAGE_COMPRESSIONTYPE._serialized_start=224
  _ZTLIVESCMESSAGE_COMPRESSIONTYPE._serialized_end=274
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ErrorMessage.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import LocaleMessage_pb2 as LocaleMessage__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x12\x45rrorMessage.proto\x12\x13\x41\x63\x46unDanmu.Im.Basic\x1a\x13LocaleMessage.proto\"J\n\x0c\x45rrorMessage\x12:\n\x0elocaleMessages\x18\x01 \x03(\x0b\x32\".AcFunDanmu.Im.Basic.LocaleMessageb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ErrorMessage_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _ERRORMESSAGE._serialized_start=64
  _ERRORMESSAGE._serialized_end=138
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: CommonActionSignalRichText.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import ZtLiveUserInfo_pb2 as ZtLiveUserInfo__pb2
import ImageCdnNode_pb2 as ImageCdnNode__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n CommonActionSignalRichText.proto\x12\nAcFunDanmu\x1a\x14ZtLiveUserInfo.proto\x1a\x12ImageCdnNode.proto\"\xef\x04\n\x1a\x43ommonActionSignalRichText\x12H\n\x08segments\x18\x01 \x03(\x0b\x32\x36.AcFunDanmu.CommonActionSignalRichText.RichTextSegment\x12\x12\n\nsendTimeMs\x18\x02 \x01(\x03\x1ax\n\x0cImageSegment\x12*\n\x08pictures\x18\x01 \x03(\x0b\x32\x18.AcFunDanmu.ImageCdnNode\x12\x17\n\x0f\x61lternativeText\x18\x02 \x01(\t\x12\x18\n\x10\x61lternativeColor\x18\x03 \x01(\t\x12\t\n\x01\x64\x18\x04 \x01(\t\x1a\x36\n\x0cPlainSegment\x12\x0c\n\x04text\x18\x01 \x01(\t\x12\r\n\x05\x63olor\x18\x02 \x01(\t\x12\t\n\x01\x63\x18\x03 \x01(\t\x1a\xf4\x01\n\x0fRichTextSegment\x12J\n\x08userInfo\x18\x01 \x01(\x0b\x32\x36.AcFunDanmu.CommonActionSignalRichText.UserInfoSegmentH\x00\x12\x44\n\x05plain\x18\x02 \x01(\x0b\x32\x33.AcFunDanmu.CommonActionSignalRichText.PlainSegmentH\x00\x12\x44\n\x05image\x18\x03 \x01(\x0b\x32\x33.AcFunDanmu.CommonActionSignalRichText.ImageSegmentH\x00\x42\t\n\x07segment\x1aJ\n\x0fUserInfoSegment\x12(\n\x04user\x18\x01 \x01(\x0b\x32\x1a.AcFunDanmu.ZtLiveUserInfo\x12\r\n\x05\x63olor\x18\x02 \x01(\tb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'CommonActionSignalRichText_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _COMMONACTIONSIGNALRICHTEXT._serialized_start=91
  _COMMONACTIONSIGNALRICHTEXT._serialized_end=714
  _COMMONACTIONSIGNALRICHTEXT_IMAGESEGMENT._serialized_start=215
  _COMMONACTIONSIGNALRICHTEXT_IMAGESEGMENT._serialized_end=335
  _COMMONACTIONSIGNALRICHTEXT_PLAINSEGMENT._serialized_start=337
  _COMMONACTIONSIGNALRICHTEXT_PLAINSEGMENT._serialized_end=391
  _COMMONACTIONSIGNALRICHTEXT_RICHTEXTSEGMENT._serialized_start=394
  _COMMONACTIONSIGNALRICHTEXT_RICHTEXTSEGMENT._serialized_end=638
  _COMMONACTIONSIGNALRICHTEXT_USERINFOSEGMENT._serialized_start=640
  _COMMONACTIONSIGNALRICHTEXT_USERINFOSEGMENT._serialized_end=714
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: CommonStateSignalChatAccept.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import ChatMediaType_pb2 as ChatMediaType__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!CommonStateSignalChatAccept.proto\x12\nAcFunDanmu\x1a\x13\x43hatMediaType.proto\"s\n\x1b\x43ommonStateSignalChatAccept\x12\x0e\n\x06\x63hatId\x18\x01 \x01(\t\x12,\n\tmediaType\x18\x02 \x01(\x0e\x32\x19.AcFunDanmu.ChatMediaType\x12\x16\n\x0e\x61ryaSignalInfo\x18\x03 \x01(\tb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'CommonStateSignalChatAccept_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _COMMONSTATESIGNALCHATACCEPT._serialized_start=70
  _COMMONSTATESIGNALCHATACCEPT._serialized_end=185
# @@protoc_insertion_point(module_scope)
